pub enum ParquetCompression {
Zstd,
Snappy,
Uncompressed,
}Expand description
Determines the compression codec for Parquet files written by Tardis replay.
Variants
Zstd
Use Zstandard compression with level 3.
Snappy
Use Snappy compression.
Uncompressed
Write uncompressed Parquet files.
Implementations
Sourceimpl ParquetCompression
impl ParquetCompression
Sourcepub fn as_parquet_compression(&self) -> Compression
pub fn as_parquet_compression(&self) -> Compression
Converts the replay config compression value to a Parquet compression value.
Panics
Panics if the hard-coded Zstandard level 3 is rejected by the Parquet crate.